@@ -80,18 +80,40 @@
 }
 
 ## Gu Wabha functions
+#' Gu and Wabha test functions
+#'
+#' @param x numeric; vector of points to evaluate the function at, on interval
+#'   (0,1)
+#'
+#' @rdname gw_functions
+#' @export
+#'
+#' @examples
+#' \dontshow{op <- options(digits = 4)}
+#' x <- seq(0, 1, length = 6)
+#' gw_f0(x)
+#' gw_f1(x)
+#' gw_f2(x)
+#' gw_f3(x) # should be constant 0
+#' \dontshow{options(op)}
 gw_f0 <- function(x) {
     2 * sin(pi * x)
 }
 
+#' @rdname gw_functions
+#' @export
 gw_f1 <- function(x) {
     exp(2 * x)
 }
 
+#' @rdname gw_functions
+#' @export
 gw_f2 <- function(x) {
     0.2 * x^11 * (10 * (1 - x))^6 + 10 * (10 * x)^3 * (1 - x)^10
 }
 
+#' @rdname gw_functions
+#' @export
 gw_f3 <- function(x) { # a null function with zero effect
     0 * x
 }
@@ -138,7 +160,7 @@ bivariate <- function(x, z, sx = 0.3, sz = 0.4) {
 #' @importFrom rlang .data
 `bivariate_model` <- function(n, sim_fun = sim_normal, scale = 2) {
     data <- tibble(x = runif(n), z = runif(n))
-    data2 <- sim_fun(x = bivariate(data$x, data$z))
+    data2 <- sim_fun(x = bivariate(data$x, data$z), scale = scale)
     data <- bind_cols(data2, data)
     data
 }
@@ -162,7 +184,8 @@ bivariate <- function(x, z, sx = 0.3, sz = 0.4) {
     data <- tibble(x0 = runif(n, 0, 1), x1 = runif(n, 0, 1),
                    x2 = sort(runif(n, 0, 1)))
     data <- mutate(data,
-                   f1 = 2 * sin(pi * .data$x2), f2 = exp(2 * .data$x2) - 3.75887,
+                   f1 = 2 * sin(pi * .data$x2), f2 = exp(2 * .data$x2) -
+                     3.75887,
                    f3 = 0.2 * .data$x2^11 * (10 * (1 - .data$x2))^6 +
                        10 * (10 * .data$x2)^3 * (1 - .data$x2)^10,
                    fac = as.factor(sample(1:3, n, replace = TRUE)))
